pub enum CredsError {
ProfainityError,
UsernameCaseMappedError,
BlacklistError,
NotAnEmail,
PasswordTooShort,
PasswordTooLong,
Argon2Error(Error),
}Expand description
Errors that can occur when processing credentials
Variants
ProfainityError
when the value passed contains profainity
UsernameCaseMappedError
when the value passed contains characters not present in UsernameCaseMapped profile
BlacklistError
when the value passed contains blacklisted words see blacklist
NotAnEmail
email validation error
PasswordTooShort
password too short
PasswordTooLong
password too long
Argon2Error(Error)
Errors from argon2